Prepare the common render data to submit a scene to the forward pipeline.

Note: When rendering multiple views of the same scene, common data only needs to be prepared once.

See [PrepareSceneForwardPipelineViewDependentRenderData].